@@ -1,8 +1,9 @@
 library("riem")
 context("stations")
 test_that("riem_stations returns the right output",{
-  skip_on_cran()
+  vcr::use_cassette("stations", {
   output <- riem_stations(network = "IN__ASOS")
+  })
   expect_is(output, "tbl_df")
   expect_is(output$id, "character")
   expect_is(output$name, "character")
@@ -12,7 +13,9 @@ test_that("riem_stations returns the right output",{
 
 
 test_that("riem_stations returns error if code does not exist",{
-  skip_on_cran()
-  expect_error(riem_stations(network = "IN__ASOS2"),
-               "IN__ASOS2 is not a valid network code")
+  vcr::use_cassette("stations-wrong-code", {
+    expect_error(riem_stations(network = "IN__ASOS2"),
+                 "IN__ASOS2 is not a valid network code")
+  })
+
 })
